@@ -14,8 +14,29 @@ public class CropTrimmer extends AbstractSingleRecordTrimmer
         public CropTrimmer(int len) {
             this.len = len;
         }        
-        
 
+        
+        
+/*
+ 	@Override
+	public FastqRecord[] processRecords(FastqRecord[] in)
+	{
+		if(in==null)
+			return null; 
+
+		FastqRecord out[]=new FastqRecord[in.length];
+		
+		for(int i=0;i<in.length;i++)
+			{
+			if(in[i]!=null)
+				out[i]=processRecord(in[i]);
+			}
+	
+		return out;
+	}
+ */
+        
+        
 	@Override
 	public FastqRecord processRecord(FastqRecord in)
 	{
